@@ -6,10 +6,9 @@
 #'
 #' @param audio_dir path to the directory with sounds
 #' @param picture_dir path to the directory with pictures
-#' @param textgrid string with a filename or path to the TextGrid
-#' @param tiers vecors of numbers or names of TextGrid tiers. They merged into a table and used in the created viewer.
-#' @param merge_column string with a column name that will be used for merging stimuli and video and audio viewer.
-#' @param caption_column string with a column name that will be used for captions for a picture (by defaul is the same as merge_column).
+#' @param table data frame with data ordered according to files in the audio folder
+#' @param captions vector of strings that will be used for captions for a picture.
+#' @param sorting_columns vector of strings for sorting the result column
 #' @param output_file the name of the result .html file (by default stimuli_viewer)
 #' @param output_dir the output directory for the rendered file
 #' @param render the logical argument, if \code{TRUE} renders the created R Markdown viewer to the \code{output_dir} folder, otherwise returns the path to the temporary file with a .csv file.
@@ -22,18 +21,15 @@
 #' @importFrom utils installed.packages
 #' @importFrom utils write.csv
 
-
 create_viewer <- function(audio_dir,
                           picture_dir,
-                          textgrid,
-                          tiers = 1,
-                          merge_column,
-                          caption_column = NULL,
-                          about = "Created with the `phonfieldworks` package (Moroz 2019).",
+                          table,
+                          captions = NULL,
+                          sorting_columns = NULL,
+                          about = "Created with the `phonfieldworks` package (Moroz 2020).",
                           output_dir,
                           output_file = "stimuli_viewer",
                           render = TRUE){
-  if(is.null(caption_column)){caption_column =  merge_column}
   if(!("DT" %in% utils::installed.packages()[,"Package"])){
     stop('For this function you need to install DT package with a command install.packages("DT").')
   }
@@ -46,37 +42,25 @@ create_viewer <- function(audio_dir,
     stop("The number of audio files is less then number of pictures.")
   }
 
-  result_df <- lapply(seq_along(tiers), function(i){
-    df <- tier_to_df(textgrid = textgrid, tier = tiers[i])
-    return(df$annotation[df$annotation != ""])
-  })
-  result_df <- as.data.frame(result_df)
-
-
-# check whether there is an empty names -----------------------------------
-  tier_names <- get_textgrid_names(textgrid)[tiers]
-  tier_names <- lapply(seq_along(tier_names), function(i){
-    ifelse(tier_names[i] == "", paste0("X", i), tier_names[i])
-  })
-  tier_names <- unlist(tier_names)
-
-# make a coumn names ------------------------------------------------------
-  colnames(result_df) <- tier_names
-
 # create correct relative paths -------------------------------------------
   audio_dir <- strsplit(normalizePath(audio_dir),
                         normalizePath(output_dir))[[1]][2]
   audio_dir <- substr(audio_dir, 2, nchar(audio_dir))
-  result_df$audio <- paste0(audio_dir, "/", audio)
+  table$audio <- paste0(audio_dir, "/", audio)
 
   picture_dir <- strsplit(normalizePath(picture_dir),
                           normalizePath(output_dir))[[1]][2]
   picture_dir <- substr(picture_dir, 2, nchar(picture_dir))
-  result_df$pictures <- paste0(picture_dir, "/", pictures)
+  table$pictures <- paste0(picture_dir, "/", pictures)
+
+  # sort rows according to sorting_columns
+  if(!is.null(sorting_columns)){
+    table <- table[do.call(order, table[sorting_columns]), ]
+  }
 
 # create a .csv file ------------------------------------------------------
   tmp1 <- tempfile(fileext = ".csv")
-  utils::write.csv(result_df, tmp1, row.names = FALSE)
+  utils::write.csv(table, tmp1, row.names = FALSE)
 
 # create about file -------------------------------------------------------
   if(substr(about, nchar(about)-3, nchar(about)) == ".Rmd"){
@@ -92,13 +76,15 @@ create_viewer <- function(audio_dir,
 "/phonfieldwork/rmarkdown/templates/annotation_viewer/skeleton/skeleton.Rmd"),
                     params = list(data = tmp1,
                                   about = tmp2,
-                                  merge_column = merge_column,
-                                  caption_column = caption_column),
+                                  captions = captions),
                     output_dir = output_dir,
                     quiet = TRUE,
                     output_file = output_file)
   message(paste0("Output created: ", output_dir, output_file, ".html"))
+  suppress_message <- file.remove(tmp1)
+  suppress_message <- file.remove(tmp2)
   } else {
     return(tmp1)
+    suppress_message <- file.remove(tmp2)
   }
 }
