@@ -5,6 +5,8 @@
 #' @author George Moroz <agricolamz@gmail.com>
 #'
 #' @param textgrid string with a filename or path to the TextGrid
+#' @param encoding TextGrid encoding. Import from \code{readLines()} function.
+#'
 #' @return a dataframe with columns:  \code{id}, \code{start}, \code{end} (if it is an interval tier -- the same as the start value), \code{annotation}, and \code{tier}
 #'
 #' @examples
@@ -12,11 +14,11 @@
 #'
 #' @export
 
-textgrid_to_df <- function(textgrid){
+textgrid_to_df <- function(textgrid, encoding = "unknown"){
   if(grepl("TextGrid", textgrid[2])){
     tg <- textgrid
   } else{
-    tg <- readLines(textgrid)
+    tg <- readLines(textgrid, encoding = encoding)
   }
   n_tiers <- as.double(regmatches(tg[7], regexpr("\\d", tg[7])))
   lapply(1:n_tiers, function(x){
